@@ -13,7 +13,10 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-prototyping-sdk/pipeline", "0.2.7", __name__[0:-6], "pipeline@0.2.7.jsii.tgz"
+    "@aws-prototyping-sdk/pipeline",
+    "0.2.12",
+    __name__[0:-6],
+    "pipeline@0.2.12.jsii.tgz",
 )
 
 __all__ = [
